Module: GitlabQuality::TestTooling::CodeCoverage::ClickHouse::Client

Included in:
JestQuarantinedTestsTable, Table, TestHealthRiskAggregator, TestHealthScoreSnapshotter
Defined in:
lib/gitlab_quality/test_tooling/code_coverage/click_house/client.rb

Overview

Memoized ClickHouse client accessor shared by Table and TestHealthRiskAggregator. Both classes need the same client construction from @url / @database / @username / @password / @logger instance variables; this module factors out the duplicated accessor without forcing one class to inherit from the other.